//   Copyright 2012 Georg-August-Universität Göttingen, Germany
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

package de.ugoe.cs.autoquest.plugin.android.guimodel;

import de.ugoe.cs.autoquest.eventcore.guimodel.ICheckBox;

/*
 * (non-Javadoc)
 * 
 * @see http://developer.android.com/reference/android/widget/CompoundButton.html
 */
/**
 * <p>
 * Class that represents compound buttons in Android GUIs. A button with two states, checked and
 * unchecked. When the button is pressed or clicked, the state changes automatically.
 * </p>
 * 
 * @version 1.0
 * @author Florian Unger
 */
public class ANDROIDCompoundButton extends ANDROIDGUIElement implements ICheckBox {
    /**
     * <p>
     * Id for object serialization.
     * </p>
     */
    private static final long serialVersionUID = 1L;

    /**
     * <p>
     * Constructor. Creates a new ANDROIDCompoundButton.
     * </p>
     * 
     * @param specification
     *            specification of created GUI element
     * @param parent
     *            parent of the created GUI element; null means that the element is a top-level
     *            window
     */
    public ANDROIDCompoundButton(ANDROIDGUIElementSpec specification, ANDROIDGUIElement parent) {
        super(specification, parent);
    }

    /*
     * (non-Javadoc)
     * 
     * @see de.ugoe.cs.autoquest.plugin.android.guimodel.ANDROIDGUIElement#getElementDescriptor()
     */
    @Override
    protected String getElementDescriptor() {
        return "CompoundButton";
    }
}
